#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   regex-pcre
version:                0.95.0.1
visibility:             public
id:                     regex-pcre-0.95.0.1-Cp22cHlfz6kFUZgDY8Q3Ru
key:                    regex-pcre-0.95.0.1-Cp22cHlfz6kFUZgDY8Q3Ru
license:                BSD-3-Clause
copyright:              Copyright (c) 2006, Christopher Kuklewicz
maintainer:             Andreas Abel
author:                 Christopher Kuklewicz
homepage:               https://wiki.haskell.org/Regular_expressions
synopsis:               PCRE Backend for "Text.Regex" (regex-base)
description:
    This package provides a <http://pcre.org/ PCRE> backend for the <//hackage.haskell.org/package/regex-base regex-base> API.

    See also <https://wiki.haskell.org/Regular_expressions> for more information.

category:               Text
abi:                    a5ad1c3efa1c7b5b7b48df448ea8f257
exposed:                True
exposed-modules:
    Text.Regex.PCRE Text.Regex.PCRE.ByteString
    Text.Regex.PCRE.ByteString.Lazy Text.Regex.PCRE.Sequence
    Text.Regex.PCRE.String Text.Regex.PCRE.Wrap

hidden-modules:         Paths_regex_pcre
import-dirs:            /usr/lib/ghc-9.6.6/site-local/regex-pcre-0.95.0.1
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/regex-pcre-0.95.0.1 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/regex-pcre-0.95.0.1 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-regex-pcre
hs-libraries:           HSregex-pcre-0.95.0.1-Cp22cHlfz6kFUZgDY8Q3Ru
extra-libraries:        pcre
extra-libraries-static: pcre
include-dirs:           /usr/include
depends:
    array-0.5.6.0 base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    regex-base-0.94.0.3-6fVrfocUW2t4u08iX8Rj6b

haddock-interfaces:     /usr/share/doc/haskell-regex-pcre/html/regex-pcre.haddock
haddock-html:           /usr/share/doc/haskell-regex-pcre/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

